Dynamical Network Analysis
===========================

The Python implementation of Dynamical Network Analysis was bulit to provide all functionalities necessary to the analysis of Molecular Dynamics (MD) simulations using the Dynamical Network Analysis method.

Install
-------

Install the latest version of Dynamical Network Analysis::

    $ pip install dynetan

For additional details, please see `INSTALL.rst`.

Tutorial
--------

For an introduction to this implementation, a jupyter notebook tutorial has been prepared and released along with its latest publication:

* Generalized correlation-based dynamical network analysis: a new high-performance approach for identifying allosteric communications in molecular dynamics trajectories. In revision (2020).

Resources and References
------------------------

For the background on Dynamical Network Analysis, see the following papers that describe its development:

* Generalized correlation-based dynamical network analysis: a new high-performance approach for identifying allosteric communications in molecular dynamics trajectories. In revision (2020).

* Experimental and computational determination of tRNA dynamics. FEBS Letters (2010). DOI: `10.1016/j.febslet.2009.11.061 <https://doi.org/10.1016/j.febslet.2009.11.061>`_

* Exit strategies for charged tRNA from GluRS. JMB (2010). DOI: `10.1016/j.jmb.2010.02.003 <https://doi.org/10.1016/j.jmb.2010.02.003>`_

* Dynamical Networks in tRNA:protein complexes. PNAS (2009). DOI: `10.1073/pnas.0810961106 <https://doi.org/10.1073/pnas.0810961106>`_

